function [OrderArray, breakpoints2] = ExponentialSim(H_Customers, samplePassed, breakpoints, O_Customers, O_Product, O_Week, meanDaysBefore, minDaysBefore, SimHorizon, Qdist)

ordIndex = 1;

%Forall customer-product combinations
for cp = 1:length(samplePassed)
    
    T = 0;
    
    %Find parameter mu for each customer-product combination, use estimator 1/avg(number of days between orders)
    
    if samplePassed(cp) == length(breakpoints)
        tempvec = O_Week(breakpoints(samplePassed(cp)):end);
    else
        tempvec = O_Week(breakpoints(samplePassed(cp)):breakpoints(samplePassed(cp) + 1));
    end
    
    tranformed2Days = zeros(1, length(tempvec));
    
    for ord = 1:length(tempvec)
        tranformed2Days(ord) = 7*tempvec(ord);
    end
    
    db = zeros(1, length(tranformed2Days) - 1);
    
    for ord = 2:length(tranformed2Days)
        db(ord-1) = tranformed2Days(ord) - tranformed2Days(ord - 1);
    end
    
    mu = 1.1*mean(db);
    mu2 = meanDaysBefore;
    
    while T < SimHorizon %Want to create order untill simulation horizon is over
        
        draw = rand;
        t = ceil(expinv(draw, mu)); %Days till next delivery
        
        OrderArray(ordIndex, 1) = T + t; %Delivery day
        T = T + t;
        OrderArray(ordIndex, 2) = O_Customers(breakpoints(samplePassed(cp)));%customer
        OrderArray(ordIndex, 4) = O_Product(breakpoints(samplePassed(cp)));%product
        OrderArray(ordIndex, 5) = ceil(T/7); %Week
        
        qdraw = rand; %Quantity
        qcum = 0;
        for q = 1:size(Qdist, 2)
            qcum = qcum + Qdist(1, q);
            if  qdraw < qcum 
                 OrderArray(ordIndex, 3) = Qdist(2, q);
                 break
            end
        end
        
        %Find arrival day
        redFlag = 1;
        while redFlag == 1
            
            draw2 = rand;
            OrderArray(ordIndex, 6) = ceil(expinv(draw2, mu2));
            
            %Draw days before delivery order arrives. Redraw if less than 3
            if ceil(expinv(draw2, mu2)) > minDaysBefore
                redFlag = 0; 
            end
        end
        
        ordIndex = ordIndex + 1;
        
    end
end

%Remove order outside the horizon

for i = 1:length(OrderArray)
    if isnan(OrderArray(i, 1)) || OrderArray(i, 1) > SimHorizon
        OrderArray(i, 1) = 0;
        OrderArray(i, 2) = 0;
        OrderArray(i, 3) = 0;
        OrderArray(i, 4) = 0;
        OrderArray(i, 5) = 0;
        OrderArray(i, 6) = 0;
    end
end
OrderArray = OrderArray(any(OrderArray,2),:);


%Find breakpoints between different customers. Breakpoints found in
%breakpoints2 function
OrderArray = sortrows(OrderArray, [2 4 1]);

c = 2;
breakpoints2 = zeros(2, length(H_Customers));
breakpoints2(1, 1) = 1;
breakpoints2(2, 1) = OrderArray(1,2);

for i = 2:size(OrderArray,1)
    if OrderArray(i, 2) ~= OrderArray(i-1, 2)
        breakpoints2(1,c) = i;
        breakpoints2(2,c) = OrderArray(i, 2);
        c = c + 1;
    end
end


for i = 1:size(OrderArray, 1)
    if OrderArray(i,1) - OrderArray(i,6) < 1
        OrderArray(i,:) = zeros(1, size(OrderArray, 2));
    end
end

OrderArray = OrderArray(any(OrderArray,2),:);

end

